<?php
  /**
   *   common_scripts/index.php
   *
   *  This file contains all the common functions and globals commons to each of the shopping cart REST activities.
   *  It also performs common validations of the REST query.
   *    
   *   @author Chris Pollett
   *   @version 2007-11-07
   *   @package shopping_cart
   * 
   */
   /*
      Globals common to all scripts
   */
   $BUSINESSES_DIR = "../businesses";
   
    $SUPPORTED_FORMATS = array("xml", "json");
    
    $DEFAULT_FORMAT = $SUPPORTED_FORMATS[0];
    
    $FORMAT = $_GET['format'];
    
    $BUSINESS_ID = $_GET['businessID'];
    
    $CUSTOMER_ID = $_GET['customerID'];
    
    $ITEM_ID = $_GET['itemID']; 

/**
 *  This function is used to check that the format GET'd in the query string is one of the formats
 *  supported by the shopping cart application
 *
 */    
function checkFormat()
{
    global $FORMAT, $SUPPORTED_FORMATS;
    
    if(in_array($FORMAT, $SUPPORTED_FORMATS))
    {
       return true;
    }
    
    return false;
}

/**
 * This function is used to make sure that a businessID was in fact GET'd to the
 * shopping cart application. It would be nice to enhance it to check if the businessID
 * was a string of the appropriate type.  
 *
 */    
function checkBusinessID()
{
    global $BUSINESS_ID;
    
    if($BUSINESS_ID) //get is a super global
    {
        return true;
    }
    
    return false;    
}

/**
 * This function is used to make sure that a customerID was in fact GET'd to the
 * shopping cart application. It would be nice to enhance it to check if the customerID
 * was a string of the appropriate type.  
 *
 */    
function validateCustomerID()
{
   global $CUSTOMER_ID;
   
    if(!$CUSTOMER_ID)
    {
        response(makeMessage("Error: customerID not provided") );
        exit(0);
    }
    
      
}

/**
 * Makes a shopping cart response message from a string in the format GET'd 
 * by the client.
 *
 * @return -- message
 */    
function makeMessage($message)
{
   global $FORMAT;
   
   $formatMakeMessage = $FORMAT."MakeMessage";
   
   return $formatMakeMessage($message);
}

/**
 * Makes a shopping cart response message from a string as JSON data
 * Called by makeMessage()
 *
 * @see -- makeMessage.
 *
 * @return -- message
 */    
function jsonMakeMessage($message)
{
   return '"'.$message.'"';
}

/**
 * Makes a shopping cart response message from a string as XML data
 * Called by makeMessage()
 *
 * @see -- makeMessage.
 *
 * @return -- message
 */    
function xmlMakeMessage($message)
{
   return "<message>$message<message>";
}

/**
 *  Prints out the response message from the shopping cart server as a string in the
 *  format that was GET'd to the server
 *
 */    
function response($message)
{
    global $FORMAT;
     
    $formatResponse = $FORMAT."Response";
     
    $formatResponse($message);
}

/**
 *  Prints out the response message from the shopping cart server as an XML string
 *  It is called from response()
 *
 * @see response
 */    
function xmlResponse($message)
{
   echo "<cart>\n$message\n</cart>";
}

/**
 *  Prints out the response message from the shopping cart server as an JSON string
 *  It is called from response()
 *
 */    
function jsonResponse($message)
{
   echo $message;
}

/**
 * @return -- whether the GET'd businessID's directory exists
 */    
function businessExists()
{
    global $BUSINESSES_DIR, $BUSINESS_ID;
    
    $businessDir =  "$BUSINESSES_DIR/$BUSINESS_ID";
    
    if(file_exists($businessDir) && filetype($businessDir) == "dir" )
    {
       return true;
    }
    else
    {
       return false;
    }
}

/**
 *  This function reads the file that store the shopping cart of the GET'd customerID to
 *  in the GET'd business' directory.
 *
 * @return -- an array of the items in the cart
 */    
function getCustomerCartArray()
{

   global $BUSINESSES_DIR, $BUSINESS_ID, $CUSTOMER_ID;
    
   $customerFile =  "$BUSINESSES_DIR/$BUSINESS_ID/$CUSTOMER_ID.txt";
   
   if(file_exists($customerFile))
   {
       $fileString = file_get_contents($customerFile);
       
       $cartArray = explode("\n", $fileString);
       if($cartArray[0] == "")
       {
          array_shift($cartArray);
       }
   }
   else
   {
       $cartArray = array();
   }

   return $cartArray;
}

/**
 *  This function writes the supplied shopping cart of the GET'd customerID to
 *  the GET'd business' directory
 *
 */    
function putCustomerCartArray($cartArray)
{
   global $BUSINESSES_DIR, $BUSINESS_ID, $CUSTOMER_ID;
    
   $customerFile =  "$BUSINESSES_DIR/$BUSINESS_ID/$CUSTOMER_ID.txt";

   $fileString = implode("\n", $cartArray);
    
   file_put_contents($customerFile, $fileString); 
}
    
    
    /*
          Checks of REST query performed by all scripts
    */    
     if(!checkFormat() )
     {
         $message = "Error: REST message format not provided or not recognized.";
         
         $FORMAT = $DEFAULT_FORMAT; 
         response( makeMessage( $message ) );
         exit(0);
     }
     if(!checkBusinessID())
     {
        $message = "Error: Business ID not provided or not in correct format";
        response( makeMessage( $message ) );
        exit(0);
     }

    /*
       The create business script might create the global $CREATE_BUSINESS
       
       Otherwise, we check if the $BUSINESS_ID corresponds to an actual business stored on our server
    */
  if(!$CREATE_BUSINESS && !businessExists())
  {
        $message = "Error: Business does not exist on server";
        response( makeMessage( $message ) );
        exit(0);  
  }
          
?>

