<?php
 
   /**
   *   contents/index.php
   *
   *  This file is used to handle the shopping cart REST contents (list items in cart) command as described in the HW3 spec.
   *    
   *   @author Chris Pollett
   *   @version 2007-11-07
   *   @uses common_scripts/index.php 
   *   @package shopping_cart
   * 
   */
   
   require_once "../common_scripts/index.php";
   
   validateCustomerID();
   
   /*
      Get array of the items in the shopping cart
   */
   $cartArray = getCustomerCartArray($_GET['businessID'], $_GET['customerID']);
   
   /*
      Cycle over array generating an output string in the desired format.
      The list commands actually create the string in the desired format.
   */   
   
   $contents = makeEmptyList();

   foreach ($cartArray as $item)
   {
       $contents = appendList( $contents, makeItem($item) );
   }
   
   response( $contents);
   
   /**
    * This function is used to create an empty shopping cart list of items in the
    * format that was GET'd to the server.
    */
   function makeEmptyList()
   {
       global $FORMAT;
       
       $formatMakeEmptyList = $FORMAT."MakeEmptyList";
       
       return $formatMakeEmptyList();
   }
   
   /**
    * This function is used to create an empty shopping cart list of items as JSON data
    * It is called by makeEmptyList()
    *
    * @see makeEmptyList
    */
   function jsonMakeEmptyList()
   {
        return "[]";
   }
   
    /**
    * This function is used to create an empty shopping cart list of items as XML data
    * It is called by makeEmptyList()
    *    
    * @see makeEmptyList
    */
   function xmlMakeEmptyList()
   {
        return "";
   }
   
   /**
    * This function is used to append a shopping cart item to the supplied shopping cart list of items in the
    * format that was GET'd to the server.
    *
    */
   function appendList($list, $item)
   {
       global $FORMAT;
       
       $formatAppendList = $FORMAT."AppendList";
       
       return $formatAppendList($list, $item);
   }

   /**
    * This function is used o append a shopping cart item to the supplied shopping cart list of items and create the output as JSON data
    * It is called by appendEmptyList()
    *
    * @see appendList
    */   
   function jsonAppendList($list, $item)
   {
       $list = rtrim($list, "]");

       if(strlen($list) > 1)
       {
           $list .=",";
       }
       
       $list .=" $item]";
       
       return $list;
   }

   /**
    * This function is used o append a shopping cart item to the supplied shopping cart list of items and create the output as XML data
    * It is called by appendEmptyList()
    *    
    * @see appendList
    */   
   function xmlAppendList($list, $item)
   {
      $list .= "\n".$item;
      
      return $list;
   }   
   
   /**
    * This function is used to create a string corresponding to a shopping cart item in
    * format that was GET'd to the server.
    *
    */   
   function makeItem($item)
   {
       global $FORMAT;
       
       $formatMakeItem = $FORMAT."MakeItem";
       
       return $formatMakeItem($item);
   }

   /**
    * This function is used to create a JSON string corresponding to a shopping cart item.
    *  It is called by makeItem
    *
    * @see makeitem
    */ 
   function jsonMakeItem($item)
   {
       return '"'.$item.'"';
   }  

   /**
    * This function is used to create a XML string corresponding to a shopping cart item.
    *  It is called by makeItem
    *
    * @see makeitem
    */
   function xmlMakeItem($item)
   {
      return "<item>$item</item>";
   }   
?>